@@ -8,4 +8,4 @@ def main(input_path=None, output_path=None):
     data = kh.parse_questions.run(inputs_path=inputs, outputs_path=outputs)
     quiz = kh.gen_quiz.run(data, 100)
     verify = kh.use_template.run(quiz=quiz, outputs_path=outputs)
-    print(verify)
+    return verify
